@@ -8,6 +8,7 @@ from sklearn.preprocessing import StandardScaler
 from sklearn.decomposition import PCA
 from scipy.spatial.distance import cdist
 from sklearn.cluster import KMeans
+from PIL import Image
 
 def sumdumbfun(x,y): # this is only here to test the package during development
     return x+y
@@ -16,7 +17,7 @@ def sumdumbfun(x,y): # this is only here to test the package during development
 def RootDir(corename, Formation_names):
     root_dir = 'CorePy'
     main_dir = ['CoreData', 'CoreOutput', 'CoreTubes']
-    sub_dir= ['CoreAttributes', 'CoreXRF']    
+    sub_dir= ['CoreAttributes', 'CoreXRF','CoreBoxPhotos']    
         
     for i in range(0, len(main_dir)):
         dirName = str(root_dir) + '/' + str(main_dir[i])
@@ -129,4 +130,13 @@ def ColorPalette(ColorScheme):
     palette = dict(zip(ColorScheme, sns.color_palette()))
     outfile = open('chemocolor','wb')
     pickle.dump(palette,outfile)
-    outfile.close()
\ No newline at end of file
+    outfile.close()
+    
+def cropCorebox(cropArea, imageFileName,imageFolder,newFolderPath):
+    imagePath = os.path.join(imageFolder, imageFileName)
+    imgOpen = Image.open(imagePath)
+    imgCrop = imgOpen.crop(cropArea)
+    croppedimagePath = os.path.join(newFolderPath, imageFileName)
+    imgCrop.save(croppedimagePath)
+    imgOpen.close()
+ 
\ No newline at end of file
